@@ -497,6 +497,22 @@ exchange_folder_get_message (CamelFolder *folder,
 	if (!ba)
 		return NULL;
 
+	while ((ba->len > 10 && g_str_has_prefix ((const gchar *)ba->data, "MAIL FROM:")) ||
+	       (ba->len >  8 && g_str_has_prefix ((const gchar *)ba->data, "RCPT TO:")) ||
+	       (ba->len >  2 && (ba->data[0] == '\n' || ba->data[1] == '\n'))) {
+		guint i;
+
+		i = 0;
+		while (i < ba->len && ba->data[i] != '\n')
+			i++;
+
+		if (i < ba->len)
+			g_byte_array_remove_range (ba, 0, i + 1);
+		else
+			break;
+	}
+
+
 	stream = camel_stream_mem_new_with_byte_array (ba);
 
 	crlffilter = camel_mime_filter_crlf_new (CAMEL_MIME_FILTER_CRLF_DECODE, CAMEL_MIME_FILTER_CRLF_MODE_CRLF_ONLY);
@@ -832,8 +848,7 @@ camel_exchange_folder_add_message (CamelExchangeFolder *exch,
 	changes = camel_folder_change_info_new ();
 	camel_folder_change_info_add_uid (changes, uid);
 	camel_folder_change_info_recent_uid (changes, uid);
-	camel_object_trigger_event (CAMEL_OBJECT (exch),
-				    "folder_changed", changes);
+	camel_folder_changed (CAMEL_FOLDER (exch), changes);
 	camel_folder_change_info_free (changes);
 	return;
 }
@@ -877,8 +892,7 @@ camel_exchange_folder_remove_message (CamelExchangeFolder *exch,
 
 	changes = camel_folder_change_info_new ();
 	camel_folder_change_info_remove_uid (changes, uid);
-	camel_object_trigger_event (CAMEL_OBJECT (exch), "folder_changed",
-				    changes);
+	camel_folder_changed (CAMEL_FOLDER (exch), changes);
 	camel_folder_change_info_free (changes);
 }
 
@@ -926,8 +940,7 @@ camel_exchange_folder_update_message_flags (CamelExchangeFolder *exch,
 
 		changes = camel_folder_change_info_new ();
 		camel_folder_change_info_change_uid (changes, uid);
-		camel_object_trigger_event (CAMEL_OBJECT (exch),
-					    "folder_changed", changes);
+		camel_folder_changed (CAMEL_FOLDER (exch), changes);
 		camel_folder_change_info_free (changes);
 	}
 }
@@ -967,8 +980,7 @@ camel_exchange_folder_update_message_flags_ex (CamelExchangeFolder *exch,
 
 		changes = camel_folder_change_info_new ();
 		camel_folder_change_info_change_uid (changes, uid);
-		camel_object_trigger_event (CAMEL_OBJECT (exch),
-					    "folder_changed", changes);
+		camel_folder_changed (CAMEL_FOLDER (exch), changes);
 		camel_folder_change_info_free (changes);
 	}
 }
@@ -1002,8 +1014,7 @@ camel_exchange_folder_update_message_tag (CamelExchangeFolder *exch,
 	camel_folder_summary_touch (folder->summary);
 	changes = camel_folder_change_info_new ();
 	camel_folder_change_info_change_uid (changes, uid);
-	camel_object_trigger_event (CAMEL_OBJECT (exch),
-				    "folder_changed", changes);
+	camel_folder_changed (CAMEL_FOLDER (exch), changes);
 	camel_folder_change_info_free (changes);
 }
 
