@@ -33,10 +33,6 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
-#include <camel/camel-provider.h>
-#include <camel/camel-url.h>
-#include <camel/camel-service.h>
-#include <camel/camel-folder.h>
 #include <e-util/e-dialog-utils.h>
 #include <e2k-validate.h>
 #include <exchange-oof.h>
@@ -54,7 +50,7 @@ GtkWidget* org_gnome_exchange_settings(EPlugin *epl, EConfigHookItemFactoryData
 GtkWidget *org_gnome_exchange_owa_url(EPlugin *epl, EConfigHookItemFactoryData *data);
 gboolean org_gnome_exchange_check_options(EPlugin *epl, EConfigHookPageCheckData *data);
 GtkWidget *org_gnome_exchange_auth_section (EPlugin *epl, EConfigHookItemFactoryData *data);
-void org_gnome_exchange_commit (EPlugin *epl, EConfigHookItemFactoryData *data);
+void org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetAccount *target_account);
 GtkWidget* org_gnome_exchange_show_folder_size_factory (EPlugin *epl, EConfigHookItemFactoryData *data);
 
 CamelServiceAuthType camel_exchange_ntlm_authtype = {
@@ -85,7 +81,7 @@ typedef struct {
 	GtkWidget *text_view;
 }OOFData;
 
-static OOFData *oof_data;
+static OOFData *oof_data = NULL;
 
 static void
 update_state (GtkTextBuffer *buffer, gpointer data)
@@ -267,7 +263,7 @@ org_gnome_exchange_settings(EPlugin *epl, EConfigHookItemFactoryData *data)
 	vbox_settings = (GtkVBox*) g_object_new (GTK_TYPE_VBOX, "homogeneous", FALSE, "spacing", 6, NULL);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox_settings), 12);
 
-	frm_oof = (GtkFrame*) g_object_new (GTK_TYPE_FRAME, "label", _("Out Of Office"), NULL);
+	frm_oof = (GtkFrame*) g_object_new (GTK_TYPE_FRAME, "label", _("Out of Office"), NULL);
 	gtk_box_pack_start (GTK_BOX (vbox_settings), GTK_WIDGET (frm_oof), FALSE, FALSE, 0);
 
 	vbox_oof = (GtkVBox*) g_object_new (GTK_TYPE_VBOX, NULL, "homogeneous", FALSE, "spacing", 12, NULL);
@@ -308,6 +304,7 @@ org_gnome_exchange_settings(EPlugin *epl, EConfigHookItemFactoryData *data)
 	gtk_text_buffer_get_bounds (buffer, &start, &end);
 	oof_message = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
 	if (oof_message && *oof_message) {
+		g_free (oof_data->message);
 		/* Will this ever happen? */
 		oof_data->message = oof_message;
 	}
@@ -369,7 +366,7 @@ org_gnome_exchange_settings(EPlugin *epl, EConfigHookItemFactoryData *data)
 	/* Folder Size */
 	lbl_fsize = (GtkLabel*) g_object_new (GTK_TYPE_LABEL, "label", _("View the size of all Exchange folders"), NULL);
 	gtk_misc_set_alignment (GTK_MISC (lbl_fsize), 0, 0.5);
-	btn_fsize = (GtkButton*) g_object_new (GTK_TYPE_BUTTON, "label", _("Folders Size"), NULL);
+	btn_fsize = (GtkButton*) g_object_new (GTK_TYPE_BUTTON, "label", _("Folder Size"), NULL);
 	g_signal_connect (btn_fsize, "clicked", G_CALLBACK (btn_fsize_clicked), NULL);
 	gtk_table_attach_defaults (tbl_misc, GTK_WIDGET (lbl_fsize), 0, 1, 0, 1);
 	gtk_table_attach (tbl_misc, GTK_WIDGET (btn_fsize), 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
@@ -732,7 +729,7 @@ org_gnome_exchange_owa_url(EPlugin *epl, EConfigHookItemFactoryData *data)
 		g_free(uri);
 	}
 
-	row = ((GtkTable *)data->parent)->nrows;
+	g_object_get (data->parent, "n-rows", &row, NULL);
 
 	hbox = gtk_hbox_new (FALSE, 6);
 	label = gtk_label_new_with_mnemonic(_("_OWA URL:"));
@@ -783,7 +780,7 @@ org_gnome_exchange_owa_url(EPlugin *epl, EConfigHookItemFactoryData *data)
 
 	row++;
 	want_mailbox_check = gtk_check_button_new_with_mnemonic (
-		_("Mailbox name is _different from user name"));
+		_("Mailbox name is _different from username"));
 	gtk_widget_show (want_mailbox_check);
 	gtk_table_attach (GTK_TABLE (data->parent), want_mailbox_check, 1, 2, row, row+1, GTK_FILL, GTK_FILL, 0, 0);
 	if (!username || !*username || !mailbox_name || !*mailbox_name ||
@@ -862,6 +859,8 @@ set_oof_info (GtkWidget *parent)
 {
 	ExchangeAccount *account;
 
+	g_return_if_fail (oof_data != NULL);
+
 	account = exchange_operations_get_exchange_account ();
 
 	if (account && !exchange_oof_set (account, oof_data->state, oof_data->message)) {
@@ -873,21 +872,24 @@ set_oof_info (GtkWidget *parent)
 static void
 destroy_oof_data (void)
 {
-	if (oof_data->message)
+	if (oof_data && oof_data->message) {
 		g_free (oof_data->message);
-	if (oof_data)
+		oof_data->message = NULL;
+	}
+
+	if (oof_data) {
 		g_free (oof_data);
+		oof_data = NULL;
+	}
 }
 
 void
-org_gnome_exchange_commit (EPlugin *epl, EConfigHookItemFactoryData *data)
+org_gnome_exchange_commit (EPlugin *epl, EMConfigTargetAccount *target_account)
 {
-	EMConfigTargetAccount *target_account;
 	const gchar *source_url;
 	CamelURL *url;
 	gint offline_status;
 
-	target_account = (EMConfigTargetAccount *)data->config->target;
 	source_url = e_account_get_string (target_account->account,  E_ACCOUNT_SOURCE_URL);
 	if (source_url && source_url[0] != '\0')
 		url = camel_url_new (source_url, NULL);
@@ -900,10 +902,6 @@ org_gnome_exchange_commit (EPlugin *epl, EConfigHookItemFactoryData *data)
 
 		return;
 	}
-	if (data->old) {
-		camel_url_free(url);
-		return;
-	}
 
 	camel_url_free (url);
 
@@ -915,7 +913,7 @@ org_gnome_exchange_commit (EPlugin *epl, EConfigHookItemFactoryData *data)
 	}
 
 	/* Set oof data in exchange account */
-	set_oof_info (data->config->target->widget);
+	set_oof_info (target_account->target.widget);
 	destroy_oof_data ();
 	return;
 }
